"""Makes a plot of FUBAR results for dN/dS analysis.

Jesse Bloom, 2013."""


import pylab
import matplotlib


def main():
    """Main body of script."""
    #
    # input / output file
    datafile = 'FUBAR_results.txt'
    plotfile = 'FUBAR_results_%s.pdf'
    sites_to_label = ['other', 259, 280, 384]
    names = ['other sites', 'site 259', 'site 280', 'site 384']
    markers = ['c.', 'r^', 'bs', 'go']
    markersizes = [4, 6, 6, 6]
    matplotlib.rc('font', size=11)
    matplotlib.rc('font', family='sans-serif')
    matplotlib.rc('legend', fontsize=11)
    #
    # read in the data
    p_ps_list = []
    p_ns_list = []
    for line in open(datafile):
        if line[0] == '#':
            continue
        entries = line.split(',')
        site = int(entries[0])
        p_ps = float(entries[4])
        p_ps_list.append((p_ps, site))
        p_ns = float(entries[5])
        p_ns_list.append((p_ns, site))
    p_ps_list.sort()
    p_ns_list.sort()
    nsites = len(p_ps_list)
    ps_sites_labeled = {'other':[]}
    ns_sites_labeled = {'other':[]}
    for i in range(nsites):
        (p_ps, r_ps) = p_ps_list[i]
        (p_ns, r_ns) = p_ns_list[i]
        if r_ps in sites_to_label:
            assert r_ps not in ps_sites_labeled
            ps_sites_labeled[r_ps] = [(i + 1, p_ps)]
        else:
            ps_sites_labeled['other'].append((i + 1, p_ps))
        if r_ns in sites_to_label:
            assert r_ns not in ns_sites_labeled
            ns_sites_labeled[r_ns] = [(i + 1, p_ns)]
        else:
            ns_sites_labeled['other'].append((i + 1, p_ns))
    for (stype, datad) in [('positive', ps_sites_labeled), ('negative', ns_sites_labeled)]:
        symbols = []
        fig = pylab.figure(figsize=(4, 3))
        (lmargin, rmargin, tmargin, bmargin) = (0.15, 0.06, 0.04, 0.17)
        ax = pylab.axes([lmargin, bmargin, 1 - lmargin - rmargin, 1 - tmargin - bmargin])
        for (label, marker, ms) in zip(sites_to_label, markers, markersizes):
            sym = pylab.plot([x[0] for x in datad[label]], [x[1] for x in datad[label]], marker, ms=ms)
            symbols.append(sym)
        labeled_names = []
        for name in names:
            if name == 'other sites':
                labeled_names.append(name)
            else:
                labeled_names.append('%s (P = %.3f)' % (name, datad[int(name.split()[1])][0][1]))
        pylab.legend(symbols, labeled_names, loc='%s' % {'positive':'upper left', 'negative':'lower right'}[stype], numpoints=1)
        pylab.ylabel('Probability %s selection' % stype)
        pylab.xlabel('Sites ordered according to probability')
        pylab.gca().set_ylim((0, 1.01))
        pylab.savefig(plotfile % stype)
        pylab.show()



main() # run the script
